# URA Token Package

This is a python wrapper to URA APIs. 

## Register for your access key with [URA](https://www.ura.gov.sg/maps/api/reg.html)

## Example:
```python
from ura_api import ura_api

ura = ura_api.ura_api('<place valid access key here>')
ura.car_pack_available_lots()
```

Questions or bugs, please write to chengguan.teo@gmail.com.
